==> cscec5b-rmat-impl-3.0.1-20230609.071328-202-sources.jar: com/ejianc/business/rmat/bean/PeriodDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 期初录入单子表
 *
 * @author generator
 *
 */
 @TableName("ejc_rmat_period_detail")
public class PeriodDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="period_id")
    private Long periodId; // 主表主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源ID
    @TableField(value="mny")
    private BigDecimal mny; // 无税金额
    @TableField(value="taxmny")
    private BigDecimal taxmny; // 含税金额
    @TableField(value="nprice")
    private BigDecimal nprice; // 无税价格
    @TableField(value="ntaxprice")
    private BigDecimal ntaxprice; // 含税价格
    @TableField(value="taxrate")
    private BigDecimal taxrate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税金
    @TableField(value="rent_date")
    private Date rentDate; // 计租日
    @TableField(value="pk_amountlist")
    private String pkAmountlist; // 分录主键
    @TableField(value="htywnr")
    private String htywnr; // 分录名称
    @TableField(value="sign_row_type")
    private Integer signRowType; //合同签订方式1-分类 2-材料
    @TableField(value="unit_id")
    private String unitId; // 档案单位主键
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位主键
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位名称
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物验收数量
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位名称
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租验收数量
    @TableField(value="nc_detail_id")
    private String ncDetailId; // NC清单主键




    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxmny() {
        return taxmny;
    }

    public void setTaxmny(BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }
    public BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    public void setNtaxprice(BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }
    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }
    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public String getNcDetailId() {
        return ncDetailId;
    }

    public void setNcDetailId(String ncDetailId) {
        this.ncDetailId = ncDetailId;
    }
}

==> cscec5b-rmat-impl-3.0.1-20241109.065542-320-sources.jar: com/ejianc/business/rmat/bean/PeriodDetailEntity.java <==
package com.ejianc.business.rmat.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 期初录入单子表
 *
 * @author generator
 *
 */
 @TableName("ejc_rmat_period_detail")
public class PeriodDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="period_id")
    private Long periodId; // 主表主键ID
    @TableField(value="material_id")
    private Long materialId; // 物资主键
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资类别
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资类别名称
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="unit")
    private String unit; // 单位
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="check_nums_sum")
    private BigDecimal checkNumsSum; // 验收数量
    @TableField(value="material_manufacturer")
    private String materialManufacturer; // 生产厂家
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="material_source_id")
    private String materialSourceId; // 物资来源ID
    @TableField(value="mny")
    private BigDecimal mny; // 无税金额
    @TableField(value="taxmny")
    private BigDecimal taxmny; // 含税金额
    @TableField(value="nprice")
    private BigDecimal nprice; // 无税价格
    @TableField(value="ntaxprice")
    private BigDecimal ntaxprice; // 含税价格
    @TableField(value="stop_price")
    private BigDecimal stopPrice; // 停租无税价格
    @TableField(value="stop_tax_price")
    private BigDecimal stopTaxPrice; // 停租含税价格
    @TableField(value="taxrate")
    private BigDecimal taxrate; // 税率
    @TableField(value="tax")
    private BigDecimal tax; // 税金
    @TableField(value="rent_date")
    private Date rentDate; // 计租日
    @TableField(value="pk_amountlist")
    private String pkAmountlist; // 分录主键
    @TableField(value="htywnr")
    private String htywnr; // 分录名称
    @TableField(value="sign_row_type")
    private Integer signRowType; //合同签订方式1-分类 2-材料
    @TableField(value="unit_id")
    private String unitId; // 档案单位主键
    @TableField(value="real_unit_id")
    private String realUnitId; // 实物单位主键
    @TableField(value="real_unit_name")
    private String realUnitName; // 实物单位名称
    @TableField(value="real_trans_scale")
    private BigDecimal realTransScale; // 实物转换系数
    @TableField(value="real_num")
    private BigDecimal realNum; // 实物验收数量
    @TableField(value="rent_unit_id")
    private String rentUnitId; // 计租单位主键
    @TableField(value="rent_unit_name")
    private String rentUnitName; // 计租单位名称
    @TableField(value="rent_trans_scale")
    private BigDecimal rentTransScale; // 计租转换系数
    @TableField(value="rent_num")
    private BigDecimal rentNum; // 计租验收数量
    @TableField(value="nc_detail_id")
    private String ncDetailId; // NC清单主键
    @TableField(value="flow_type")
    private String flowType; // 流水类型: 1-验收，2-停用，3-启用，4-退赔，5-遗失
    @TableField(value="in_out_flag")
    private Integer inOutFlag; // 进退场属性1进场2退场
    @TableField(value="use_status")
    private String useStatus; // 使用状态：0-停用，1-启用
    @TableField(value="busi_type")
    private String busiType; //业务类型


    public Long getPeriodId() {
        return periodId;
    }

    public void setPeriodId(Long periodId) {
        this.periodId = periodId;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getUnit() {
        return unit;
    }

    public void setUnit(String unit) {
        this.unit = unit;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public BigDecimal getCheckNumsSum() {
        return checkNumsSum;
    }

    public void setCheckNumsSum(BigDecimal checkNumsSum) {
        this.checkNumsSum = checkNumsSum;
    }
    public String getMaterialManufacturer() {
        return materialManufacturer;
    }

    public void setMaterialManufacturer(String materialManufacturer) {
        this.materialManufacturer = materialManufacturer;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getMaterialSourceId() {
        return materialSourceId;
    }

    public void setMaterialSourceId(String materialSourceId) {
        this.materialSourceId = materialSourceId;
    }
    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getTaxmny() {
        return taxmny;
    }

    public void setTaxmny(BigDecimal taxmny) {
        this.taxmny = taxmny;
    }
    public BigDecimal getNprice() {
        return nprice;
    }

    public void setNprice(BigDecimal nprice) {
        this.nprice = nprice;
    }
    public BigDecimal getNtaxprice() {
        return ntaxprice;
    }

    public void setNtaxprice(BigDecimal ntaxprice) {
        this.ntaxprice = ntaxprice;
    }
    public BigDecimal getTaxrate() {
        return taxrate;
    }

    public BigDecimal getStopPrice() {
        return stopPrice;
    }

    public void setStopPrice(BigDecimal stopPrice) {
        this.stopPrice = stopPrice;
    }

    public BigDecimal getStopTaxPrice() {
        return stopTaxPrice;
    }

    public void setStopTaxPrice(BigDecimal stopTaxPrice) {
        this.stopTaxPrice = stopTaxPrice;
    }

    public void setTaxrate(BigDecimal taxrate) {
        this.taxrate = taxrate;
    }
    public BigDecimal getTax() {
        return tax;
    }

    public void setTax(BigDecimal tax) {
        this.tax = tax;
    }
    public Date getRentDate() {
        return rentDate;
    }

    public void setRentDate(Date rentDate) {
        this.rentDate = rentDate;
    }
    public String getPkAmountlist() {
        return pkAmountlist;
    }

    public void setPkAmountlist(String pkAmountlist) {
        this.pkAmountlist = pkAmountlist;
    }
    public String getHtywnr() {
        return htywnr;
    }

    public void setHtywnr(String htywnr) {
        this.htywnr = htywnr;
    }

    public Integer getSignRowType() {
        return signRowType;
    }

    public void setSignRowType(Integer signRowType) {
        this.signRowType = signRowType;
    }

    public String getUnitId() {
        return unitId;
    }

    public void setUnitId(String unitId) {
        this.unitId = unitId;
    }

    public String getRealUnitId() {
        return realUnitId;
    }

    public void setRealUnitId(String realUnitId) {
        this.realUnitId = realUnitId;
    }

    public String getRealUnitName() {
        return realUnitName;
    }

    public void setRealUnitName(String realUnitName) {
        this.realUnitName = realUnitName;
    }

    public BigDecimal getRealTransScale() {
        return realTransScale;
    }

    public void setRealTransScale(BigDecimal realTransScale) {
        this.realTransScale = realTransScale;
    }

    public BigDecimal getRealNum() {
        return realNum;
    }

    public void setRealNum(BigDecimal realNum) {
        this.realNum = realNum;
    }

    public String getRentUnitId() {
        return rentUnitId;
    }

    public void setRentUnitId(String rentUnitId) {
        this.rentUnitId = rentUnitId;
    }

    public String getRentUnitName() {
        return rentUnitName;
    }

    public void setRentUnitName(String rentUnitName) {
        this.rentUnitName = rentUnitName;
    }

    public BigDecimal getRentTransScale() {
        return rentTransScale;
    }

    public void setRentTransScale(BigDecimal rentTransScale) {
        this.rentTransScale = rentTransScale;
    }

    public BigDecimal getRentNum() {
        return rentNum;
    }

    public void setRentNum(BigDecimal rentNum) {
        this.rentNum = rentNum;
    }

    public String getNcDetailId() {
        return ncDetailId;
    }

    public void setNcDetailId(String ncDetailId) {
        this.ncDetailId = ncDetailId;
    }

    public String getFlowType() {
        return flowType;
    }

    public void setFlowType(String flowType) {
        this.flowType = flowType;
    }

    public Integer getInOutFlag() {
        return inOutFlag;
    }

    public void setInOutFlag(Integer inOutFlag) {
        this.inOutFlag = inOutFlag;
    }

    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }

    public String getBusiType() {
        return busiType;
    }

    public void setBusiType(String busiType) {
        this.busiType = busiType;
    }
}
